@@ -64,7 +64,7 @@ def upload_sample(sample_name, sample_data, sample_type, dns_data=None):
         Return data will contain status codes (result.status_code), and JSON-encoded information (in result.text)
         containing:
             + error: Boolean identifying if there was an error
-            + body: a message about acceptance of the sample
+            + body: a dictionary containing the sample UUID for the file
     """
 
     upload_url = "https://api.seclarity.io/upload/v1.0/uploader"
@@ -132,7 +132,8 @@ def list_my_samples():
 
 def get_uuid_for_uploaded_sample(sample_name, upload_time_utc, get_public_uuid=False):
     """Wraps a couple of APIs to help a user find a sample that has been
-        uploaded at a (roughly) known time. Expects the upload_time to be in epoch time as an integer.
+        uploaded at a (roughly) known time. Expects the upload_time to be in epoch time as an integer. Use this when you
+        haven't just uploaded the sample. Otherwise, get the UUID from the upload_sample() call.
     """
 
     files_list = list_my_samples()
